Module shared

Module shared 

Structs

EncryptionKey
Represents an Encryption key used to encrypt and decrypt requests
ExportableEncryptionKeyData
Reusable encryption key data for client parsing

Constants

NCRYPTF_CONTENT_TYPE
The Ncryptf JSON content type
NCRYPTF_DRIFT_ALLOWANCE
The amount of time (in either direction) a request time may differ by and still be accepted.