pub struct Request { /* private fields */ }

Implementations

Encrypts a message with a given public key

Returns the message, if it has been set

Encrypts a message with a given public key, none, and version identifier

Returns the nonce

Signs the given data, then returns a detached signature

Creates a new request from a given secret key and signature secret key